<?php

namespace Teknisa\CNC\Services;

use Teknisa\CNC\Utilities;
use Teknisa\CNC\Factories;

use Teknisa\Libs\Util\Environment;

class Cnc00100Criterio {

	protected $entityManager;
	protected $util;
	protected $criterioFactory;
	protected $environment;

	public function __construct(\Doctrine\ORM\EntityManager $entityManager, Utilities\UtilCNC $util, 
	Factories\Cnc00100CriterioFactory $criterioFactory, Environment $environment)  {
		$this->entityManager 	= $entityManager;
		$this->util             = $util;
		$this->criterioFactory  = $criterioFactory;
		$this->environment = $environment;
	}

	public function getStandarts($params) {

		$NRADQUIRENTE = $params[0]['value'];

		$params = array(
			':NRADQUIRENTE' => $NRADQUIRENTE
		);

		$standarts = $this->criterioFactory->getStandarts($params);
		return $standarts;
	}
	
	public function findCriterio($params) {
        $NRADQUIRENTE = $params[0]['value'];
        $NRVALIDACAOADQ = $params[1]['value'];

		$params = array(
			':NRADQUIRENTE'   => $NRADQUIRENTE,
			':NRVALIDACAOADQ' => $NRVALIDACAOADQ
		);

		$standarts = $this->criterioFactory->getOrderStandard($params);

		return $standarts;
	}
	
	public function findCriterioEst($params) {

        $NRADQUIRENTE	   = $params[0]['value'];
		$NRESTABELEC       = $params[1]['value'];
		$NRVALIDACAOADQEST = $params[2]['value'];
		$params = array(
			':NRESTABELEC' 		 => $NRESTABELEC,
			':NRADQUIRENTE'      => $NRADQUIRENTE,
			':NRVALIDACAOADQEST' => $NRVALIDACAOADQEST 
		);

		$standarts = $this->criterioFactory->getEstabelecStandard($params);
		if(count($standarts) == 0){
			$paramsFilter = [$NRADQUIRENTE, $NRESTABELEC];
			return $standarts + $paramsFilter;
		} else {
			return $standarts;
		}
	}
	
	public function findCriterioOrder($params) {

        $NRADQUIRENTE = $params[0]['value'];

		$params = array(
			':NRADQUIRENTE' 	=> $NRADQUIRENTE
		);

		$standarts = $this->criterioFactory->getOrderStandarts($params);

		return $standarts;
	}
	
	public function findCriterioOrderCad($params) {

        $NRADQUIRENTE = $params[0]['value'];
        $NRORDEM = $params[1]['value'];
		$params = array(
			':NRADQUIRENTE' => $NRADQUIRENTE,
			':NRORDEM' 	    => $NRORDEM
		);
		$standarts = $this->criterioFactory->getOrderStandartsCad($params);
		return $standarts;
	}
	
	public function findCriterioOrderEstCad($params) {

        $NRADQUIRENTE = $params[0]['value'];
        $NRESTABELEC  = $params[1]['value'];
        $NRORDEM      = $params[2]['value'];
		$params = array(
			':NRADQUIRENTE' => $NRADQUIRENTE,
			':NRESTABELEC' 	=> $NRESTABELEC,
			':NRORDEM' 	    => $NRORDEM
		);
		$standarts = $this->criterioFactory->getOrderStandartsEstCad($params);
		return $standarts;
	}
	
	public function findCriterioOrderEst($params) {
		

        $NRADQUIRENTE = $params[0]['value'];
        $NRESTABELEC  = $params[1]['value'];

		$params = array(
			':NRADQUIRENTE' => $NRADQUIRENTE,
			':NRESTABELEC' 	=> $NRESTABELEC
		);

		$standarts = $this->criterioFactory->getOrderStandartsEst($params);

		return $standarts;
	}
	
	public function insertOrderStandarts ($params) {
        if(!isset($params[0]["IsCadAut"])){
			$result = $this->criterioFactory->validateOrderStandartsIns(array(
	            ":NRADQUIRENTE" => $params[0]["NRADQUIRENTE"],
	            ":NRORDEM"      => $params[0]["NRORDEM"]
	        ));
	        if (count($result) > 0)
	            throw new \Exception('ORDERSTD', 6);
        }
		$currentTime = $this->environment->getCurrentTime()->format("d/m/Y H:i:s");
		$NRORDEM        = $params[0]['NRORDEM'];
		$NRDIASTOL      = $params[0]['NRDIASTOL'];
        $NRADQUIRENTE   = $params[0]['NRADQUIRENTE'];
        $IDNSU          = $params[0]['IDNSU'];
        $IDNSUPOS       = $params[0]['IDNSUPOS'];
        $IDTOLERANCIA   = $params[0]['IDTOLERANCIA'];
        $IDBANCO        = $params[0]['IDBANCO'];
        $IDAGENCIA      = $params[0]['IDAGENCIA'];
        $IDCONTCORR     = $params[0]['IDCONTCORR'];
        $IDPRODUTOADQ   = $params[0]['IDPRODUTOADQ'];
        $IDADQUIRENTE   = $params[0]['IDADQUIRENTE'];
        $IDBANDEIRA     = $params[0]['IDBANDEIRA'];
        $IDAJUSTEAUT    = $params[0]['IDAJUSTEAUT'];
        $IDDTVENCIMENTO = $params[0]['IDDTVENCIMENTO'];
        
        $NRORG = $this->environment->getNrOrgTrab();
        $IDATIVO = isset($row['IDATIVO']) ? ($row['IDATIVO'] ?: 'S') : 'S';
        $DTULTATU = $currentTime;
        $NRORGULTATU = $this->environment->getNrOrgTrab();
        $CDOPERULTATU = $this->environment->getCdOperador();

        $NRVALIDACAOADQ = $this->util->newCode('VALIDACAOADQ', '10');
        $NRVALIDACAOADQ = intval($NRVALIDACAOADQ);
		$params = array(
			':NRORDEM' 		    => $NRORDEM,
			':NRDIASTOL' 		=> $NRDIASTOL,
			':NRADQUIRENTE'     => $NRADQUIRENTE,
			':NRVALIDACAOADQ'   => $NRVALIDACAOADQ,
			':IDNSU' 	        => $IDNSU,
			':IDNSUPOS'     	=> $IDNSUPOS,
			':IDTOLERANCIA' 	=> $IDTOLERANCIA,
			':IDBANCO' 	    	=> $IDBANCO,
			':IDAGENCIA'    	=> $IDAGENCIA,
			':IDCONTCORR' 		=> $IDCONTCORR,
			':IDPRODUTOADQ' 	=> $IDPRODUTOADQ,
			':IDADQUIRENTE' 	=> $IDADQUIRENTE,
			':IDBANDEIRA' 		=> $IDBANDEIRA,
			':IDAJUSTEAUT' 		=> $IDAJUSTEAUT,
			':IDDTVENCIMENTO'   => $IDDTVENCIMENTO
		);
		$standarts = $this->criterioFactory->insertOrderStandarts($params);
		return $standarts;
	}
	
	public function insertOrderStandartsEst ($params) {
		if(!isset($params[0]["IsCadAut"])){
			$result = $this->criterioFactory->validateOrderStandartsEstIns(array(
	            ":NRADQUIRENTE" => $params[0]["NRADQUIRENTE"],
	            ":NRESTABELEC"  => $params[0]["NRESTABELEC"],
	            ":NRORDEM"      => $params[0]["NRORDEM"]
	        ));
	        if (count($result) > 0)
	            throw new \Exception('ORDERSTDEST', 7);
		}
		$NRORDEM        = $params[0]['NRORDEM'];
		$NRDIASTOL      = $params[0]['NRDIASTOL'];
        $NRADQUIRENTE   = $params[0]['NRADQUIRENTE'];
        $NRESTABELEC    = $params[0]['NRESTABELEC'];
        $IDNSU          = $params[0]['IDNSU'];
        $IDNSUPOS       = $params[0]['IDNSUPOS'];
        $IDTOLERANCIA   = $params[0]['IDTOLERANCIA'];
        $IDBANCO        = $params[0]['IDBANCO'];
        $IDAGENCIA      = $params[0]['IDAGENCIA'];
        $IDCONTCORR     = $params[0]['IDCONTCORR'];
        $IDPRODUTOADQ   = $params[0]['IDPRODUTOADQ'];
        $IDADQUIRENTE   = $params[0]['IDADQUIRENTE'];
        $IDBANDEIRA     = $params[0]['IDBANDEIRA'];
        $IDAJUSTEAUT    = $params[0]['IDAJUSTEAUT'];
        $IDDTVENCIMENTO = $params[0]['IDDTVENCIMENTO'];

        $NRVALIDACAOADQEST = $this->util->newCode('VALIDACAOADQEST', '10');
        $NRVALIDACAOADQEST = intval($NRVALIDACAOADQEST);
		$params = array(
			':NRORDEM' 		     => $NRORDEM,
			':NRDIASTOL' 		 => $NRDIASTOL,
			':NRADQUIRENTE'      => $NRADQUIRENTE,
			':NRESTABELEC'       => $NRESTABELEC,
			':NRVALIDACAOADQEST' => $NRVALIDACAOADQEST,
			':IDNSU' 	         => $IDNSU,
			':IDNSUPOS'     	 => $IDNSUPOS,
			':IDTOLERANCIA' 	 => $IDTOLERANCIA,
			':IDBANCO' 	    	 => $IDBANCO,
			':IDAGENCIA'    	 => $IDAGENCIA,
			':IDCONTCORR' 		 => $IDCONTCORR,
			':IDPRODUTOADQ' 	 => $IDPRODUTOADQ,
			':IDADQUIRENTE' 	 => $IDADQUIRENTE,
			':IDBANDEIRA' 		 => $IDBANDEIRA,
			':IDAJUSTEAUT' 		 => $IDAJUSTEAUT,
			':IDDTVENCIMENTO'    => $IDDTVENCIMENTO
		);
		$standarts = $this->criterioFactory->insertOrderStandartsEst($params);
		return $standarts;
	}
	
	public function updateOrderStandarts ($params) {
		if(!isset($params[0]["IsCadAut"])){
			$result = $this->criterioFactory->validateOrderStandartsUpdt(array(
	            ":NRADQUIRENTE"    => $params[0]["NRADQUIRENTE"],
	            ":NRORDEM"         => $params[0]["NRORDEM"],
	            ":NRVALIDACAOADQ" => $params[0]["NRVALIDACAOADQ"],
	        ));
	        if (count($result) > 0)
	            throw new \Exception('ORDERSTD', 6);
		}
		$NRORDEM        = $params[0]['NRORDEM'];
		$NRDIASTOL      = $params[0]['NRDIASTOL'];
        $NRADQUIRENTE   = $params[0]['NRADQUIRENTE'];
        $NRVALIDACAOADQ = $params[0]['NRVALIDACAOADQ'];
        $IDNSU          = $params[0]['IDNSU'];
        $IDNSUPOS       = $params[0]['IDNSUPOS'];
        $IDTOLERANCIA   = $params[0]['IDTOLERANCIA'];
        $IDBANCO        = $params[0]['IDBANCO'];
        $IDAGENCIA      = $params[0]['IDAGENCIA'];
        $IDCONTCORR     = $params[0]['IDCONTCORR'];
        $IDPRODUTOADQ   = $params[0]['IDPRODUTOADQ'];
        $IDADQUIRENTE   = $params[0]['IDADQUIRENTE'];
        $IDBANDEIRA     = $params[0]['IDBANDEIRA'];
        $IDAJUSTEAUT    = $params[0]['IDAJUSTEAUT'];
        $IDDTVENCIMENTO = $params[0]['IDDTVENCIMENTO'];

		$paramethers = array(
			':NRORDEM' 	      => $NRORDEM,
			':NRDIASTOL' 	  => $NRDIASTOL,
			':NRADQUIRENTE'   => $NRADQUIRENTE,
			':NRVALIDACAOADQ' => $NRVALIDACAOADQ,
			':IDNSU' 	      => $IDNSU,
			':IDNSUPOS'       => $IDNSUPOS,
			':IDTOLERANCIA'   => $IDTOLERANCIA,
			':IDBANCO' 	      => $IDBANCO,
			':IDAGENCIA'      => $IDAGENCIA,
			':IDCONTCORR' 	  => $IDCONTCORR,
			':IDPRODUTOADQ'   => $IDPRODUTOADQ,
			':IDADQUIRENTE'   => $IDADQUIRENTE,
			':IDBANDEIRA' 	  => $IDBANDEIRA,
			':IDAJUSTEAUT' 	  => $IDAJUSTEAUT,
			':IDDTVENCIMENTO' => $IDDTVENCIMENTO
		);
		$standarts = $this->criterioFactory->updateOrderStandarts($paramethers);
		return $standarts;
	}
	
	public function updateOrderStandartsEst ($params) {
		if(!isset($params[0]["IsCadAut"])){
			$result = $this->criterioFactory->validateOrderStandartsEstUpdt(array(
	            ":NRADQUIRENTE" 	 => $params[0]["NRADQUIRENTE"],
	            ":NRESTABELEC"  	 => $params[0]["NRESTABELEC"],
	            ":NRORDEM"           => $params[0]["NRORDEM"],
	            ":NRVALIDACAOADQEST" => $params[0]["NRVALIDACAOADQEST"]
	        ));
	        if (count($result) > 0)
	            throw new \Exception('ORDERSTDEST', 7);
		}
		$NRORDEM           = $params[0]['NRORDEM'];
		$NRDIASTOL         = $params[0]['NRDIASTOL'];
        $NRADQUIRENTE      = $params[0]['NRADQUIRENTE'];
        $NRESTABELEC       = $params[0]['NRESTABELEC'];
        $NRVALIDACAOADQEST = $params[0]['NRVALIDACAOADQEST'];
        $IDNSU             = $params[0]['IDNSU'];
        $IDNSUPOS          = $params[0]['IDNSUPOS'];
        $IDTOLERANCIA      = $params[0]['IDTOLERANCIA'];
        $IDBANCO           = $params[0]['IDBANCO'];
        $IDAGENCIA         = $params[0]['IDAGENCIA'];
        $IDCONTCORR        = $params[0]['IDCONTCORR'];
        $IDPRODUTOADQ      = $params[0]['IDPRODUTOADQ'];
        $IDADQUIRENTE      = $params[0]['IDADQUIRENTE'];
        $IDBANDEIRA        = $params[0]['IDBANDEIRA'];
        $IDAJUSTEAUT       = $params[0]['IDAJUSTEAUT'];
        $IDDTVENCIMENTO    = $params[0]['IDDTVENCIMENTO'];

		$paramethers = array(
			':NRORDEM' 	         => $NRORDEM,
			':NRDIASTOL' 		 => $NRDIASTOL,
			':NRADQUIRENTE'      => $NRADQUIRENTE,
			':NRESTABELEC'       => $NRESTABELEC,
			':NRVALIDACAOADQEST' => $NRVALIDACAOADQEST,
			':IDNSU' 	         => $IDNSU,
			':IDNSUPOS'          => $IDNSUPOS,
			':IDTOLERANCIA'      => $IDTOLERANCIA,
			':IDBANCO' 	         => $IDBANCO,
			':IDAGENCIA'         => $IDAGENCIA,
			':IDCONTCORR' 	     => $IDCONTCORR,
			':IDPRODUTOADQ'      => $IDPRODUTOADQ,
			':IDADQUIRENTE'      => $IDADQUIRENTE,
			':IDBANDEIRA' 	     => $IDBANDEIRA,
			':IDAJUSTEAUT' 	     => $IDAJUSTEAUT,
			':IDDTVENCIMENTO'    => $IDDTVENCIMENTO
		);
		$standarts = $this->criterioFactory->updateOrderStandartsEst($paramethers);
		return $standarts;
	}
	
	public function clearOrderStandarts ($params) {
        $NRADQUIRENTE   = $params[0]['NRADQUIRENTE'];
		$NRVALIDACAOADQ = $params[0]['NRVALIDACAOADQ'];

		$paramethers = array(
			':NRADQUIRENTE'   => $NRADQUIRENTE,
			':NRVALIDACAOADQ' => $NRVALIDACAOADQ
		);

		$standarts = $this->criterioFactory->clearOrderStandarts($paramethers);
		return $standarts;
	}
	
	public function clearOrderStandartsEst ($params) {
        $NRADQUIRENTE      = $params[0]['NRADQUIRENTE'];
		$NRVALIDACAOADQEST = $params[0]['NRVALIDACAOADQEST'];
		$NRESTABELEC       = $params[0]['NRESTABELEC'];

		$paramethers = array(
			':NRADQUIRENTE'      => $NRADQUIRENTE,
			':NRVALIDACAOADQEST' => $NRVALIDACAOADQEST,
			':NRESTABELEC'       => $NRESTABELEC,
			
		);

		$standarts = $this->criterioFactory->clearOrderStandartsEst($paramethers);
		return $standarts;
	}
	
	public function clearEstabelecStandarts ($params) {
        $NRADQUIRENTE   = $params[0]['NRADQUIRENTE'];
		$NRESTABELEC    = $params[0]['NRESTABELEC'];

		$paramethers = array(
			':NRADQUIRENTE'   => $NRADQUIRENTE,
			':NRESTABELEC' 	  => $NRESTABELEC
		);

		$standarts = $this->criterioFactory->clearEstabelecStandarts($paramethers);
		return $standarts;
	}

}