<?php 

namespace WebServiceCall\Log;

class FileLogger {
    public const INFO = 'INFO';
    public const ERROR = 'ERR';
    
    private const MIN_LOG_SIZE = 0;
    private const MAX_LOG_SIZE = 8000;
    private const TEKNISA_DEFAULT_FILE_PERMISSION = 0777;
    
    private const LOG_DATE_FORMAT = 'd_m_Y__H_i_s';
    
    private const LOGS_FOLDER = "cnc_ws";
    
    private static $initialLogDate;
    private static $instance;
    private $logsPath;
    
    private function __construct() {
        $this->logsPath =   sys_get_temp_dir() . DIRECTORY_SEPARATOR . 
                            self::LOGS_FOLDER . DIRECTORY_SEPARATOR . 
                            $_POST['NRORG'] . DIRECTORY_SEPARATOR;
                            
        try {
            unlink($this->getLogFilePath());
            mkdir($this->logsPath, self::TEKNISA_DEFAULT_FILE_PERMISSION, true);
        } catch(\Exception $e) {
            throw new \Exception ("Não foi possível recriar o diretório dos logs." . $e->getMessage());       
        }
    }
    
    private static function initLogDate() {
        if(!self::$initialLogDate) {
            self::$initialLogDate = date(self::LOG_DATE_FORMAT);
        }
    }

    private function formatMsg($msg, $level) {
        $fullMsg = PHP_EOL .  date(self::LOG_DATE_FORMAT) . ' -> ' . $level . PHP_EOL .
                   trim($msg) . PHP_EOL;

        return substr($fullMsg, self::MIN_LOG_SIZE, self::MAX_LOG_SIZE);
    }
    
    private function getLogFilePath() {
        return $this->logsPath . "cnc_webservice_" . self::$initialLogDate . "_log";
    }

    public static function log($message, $level = self::INFO) {
        if(!self::$instance) {
            self::initLogDate();
            self::$instance = new self;
        }
        
        return file_put_contents(
            self::$instance->getLogFilePath(), 
            self::$instance->formatMsg($message, $level),
            FILE_APPEND
        );
    }
}